pub struct GetFieldAutoCompleteForQueryStringParams {
pub field_name: Option<String>,
pub field_value: Option<String>,
pub predicate_name: Option<String>,
pub predicate_value: Option<String>,
}Expand description
struct for passing parameters to the method get_field_auto_complete_for_query_string
Fields
field_name: Option<String>The name of the field.
field_value: Option<String>The partial field item name entered by the user.
predicate_name: Option<String>The name of the CHANGED operator predicate for which the suggestions are generated. The valid predicate operators are by, from, and to.
predicate_value: Option<String>The partial predicate item name entered by the user.