pub struct FieldReferenceData {
pub value: Option<String>,
pub display_name: Option<String>,
pub orderable: Option<Orderable>,
pub searchable: Option<Searchable>,
pub auto: Option<Auto>,
pub cfid: Option<String>,
pub operators: Option<Vec<String>>,
pub types: Option<Vec<String>>,
}Expand description
FieldReferenceData : Details of a field that can be used in advanced searches.
Fields
value: Option<String>The field identifier.
display_name: Option<String>The display name contains the following: * for system fields, the field name. For example, Summary. * for collapsed custom fields, the field name followed by a hyphen and then the field name and field type. For example, Component - Component[Dropdown]. * for other custom fields, the field name followed by a hyphen and then the custom field ID. For example, Component - cf[10061].
orderable: Option<Orderable>Whether the field can be used in a query’s ORDER BY clause.
searchable: Option<Searchable>Whether the content of this field can be searched.
auto: Option<Auto>Whether the field provide auto-complete suggestions.
cfid: Option<String>If the item is a custom field, the ID of the custom field.
operators: Option<Vec<String>>The valid search operators for the field.
types: Option<Vec<String>>The data types of items in the field.
Implementations
Sourceimpl FieldReferenceData
impl FieldReferenceData
Sourcepub fn new() -> FieldReferenceData
pub fn new() -> FieldReferenceData
Details of a field that can be used in advanced searches.